Subst

Struct Subst 

pub struct Subst { /* private fields */ }
A substitution mapping type variables to types.

Implementations

Source

impl Subst

pub fn new() -> Self

Creates an empty substitution.

pub fn insert(&mut self, var: &TyVar, ty: Ty)

Inserts a mapping from a type variable to a type.

pub fn get(&self, var: &TyVar) -> Option<&Ty>

Looks up a type variable in the substitution.

pub fn contains(&self, var: &TyVar) -> bool

Checks if a type variable has a mapping in this substitution.

pub fn apply(&self, ty: &Ty) -> Ty

Applies this substitution to a type.

pub fn apply_nat(&self, n: &TyNat) -> TyNat

Applies this substitution to a type-level natural.

pub fn apply_ty_list(&self, l: &TyList) -> TyList

Applies this substitution to a type-level list.

pub fn compose(&self, other: &Self) -> Self

Composes two substitutions: (self . other)

pub fn is_empty(&self) -> bool

Returns true if this substitution is empty.