pub struct Subst { /* private fields */ }Expand description
A substitution mapping type variables to types.
Implementations
Sourceimpl Subst
impl Subst
Sourcepub fn insert(&mut self, var: &TyVar, ty: Ty)
pub fn insert(&mut self, var: &TyVar, ty: Ty)
Inserts a mapping from a type variable to a type.
Sourcepub fn contains(&self, var: &TyVar) -> bool
pub fn contains(&self, var: &TyVar) -> bool
Checks if a type variable has a mapping in this substitution.
Sourcepub fn apply_ty_list(&self, l: &TyList) -> TyList
pub fn apply_ty_list(&self, l: &TyList) -> TyList
Applies this substitution to a type-level list.